@@ -3,9 +3,8 @@ package Net::DNS::Native;
 use strict;
 use XSLoader;
 use Socket ();
-use Config ();
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
 	INET_ATON     => 0,
@@ -142,19 +141,17 @@ Net::DNS::Native - non-blocking system DNS resolver
 
 This class provides several methods for host name resolution. It is designed to be used with event loops. All resolving are done
 by getaddrinfo(3) implemented in your system library. Since getaddrinfo() is blocking function and we don't want to block,
-call to this function will be done in separate thread. This class uses system native threads and not perl threads. So overhead
-shouldn't bee too big.
+calls to this function will be done in separate thread. This class uses system native threads and not perl threads. So overhead
+shouldn't be too big.
 
-=head1 WARNING
+=head1 INSTALLATION WARNING
 
-To support threaded extensions like this one your perl should be linked with threads library. One of the possible solution
-is to build your perl with perl threads support using C<-Dusethreads> for C<Configure> script. But it is not necessary to
-build threaded perl. So, other solution is to not use C<-Dusethreads> and instead use C<-A prepend:libswanted="pthread ">.
-This will link your perl executable with libpthread.
+To support threaded extensions like this one your perl should be linked with threads library. At the installation time
+this module will check is your perl is good enough and will not install if not.
 
-If this conditions are not met you may get segfault. To check it run this oneliner:
-
-	perl -MConfig -le 'print $Config{usethreads}||$Config{libs}=~/-l?pthread\b/ ? "this perl may use threaded library" : "this perl may segfault with threaded library"'
+One of the possible solution to make your perl compatible with this module is to build perl with perl threads support
+using C<-Dusethreads> for C<Configure> script. Other solution is to use C<-A prepend:libswanted="pthread ">, which will
+just link non-threaded perl with pthreads.
 
 =head1 METHODS
 
